==> jc-1.4.0.tar.gz: polyglot/ext/jl/ast/SourceCollection__5fc.h <==
// public class polyglot.ext.jl.ast.SourceCollection_c

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 687ec145cf1dbf5b polyglot_ext_jl_ast_Node__5fc
// @dep_class d7850567a307465c polyglot_ext_jl_ast_SourceCollection__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_ast_Node__5fc

#include "polyglot/ext/jl/ast/Node__5fc.h"

#ifndef _JC_polyglot_ext_jl_ast_SourceCollection__5fc_H_
#define _JC_polyglot_ext_jl_ast_SourceCollection__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_SourceCollection$object;
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object;
struct _jc_polyglot_util_CodeWriter$object;
struct _jc_polyglot_util_Position$object;
struct _jc_polyglot_visit_NodeVisitor$object;
struct _jc_polyglot_visit_PrettyPrinter$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$sub_refs	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$sub_nonrefs	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$refs	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$refs;
typedef struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$nonrefs	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$object;

typedef struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$fields_struct	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$fields_struct;
typedef const struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$vmethods	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtable	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtype	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtype;

// Class fields structure
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$fields_struct {
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24SourceFile;
};
extern _jc_polyglot_ext_jl_ast_SourceCollection__5fc$fields_struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$class_fields;

// Constructors
extern void _jc_polyglot_ext_jl_ast_SourceCollection__5fc$method$_init$a1fe22b707e2a2a8(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_polyglot_util_Position$object *, struct _jc_object *);

// Virtual methods
extern void _jc_polyglot_ext_jl_ast_SourceCollection__5fc$method$prettyPrint$323ca37cb40f93d3(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_polyglot_visit_PrettyPrinter$object *);
extern struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *_jc_polyglot_ext_jl_ast_SourceCollection__5fc$method$reconstruct$1013d1f0a1e6915f(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_SourceCollection__5fc$method$sources$c7962ae651ac0609(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_SourceCollection__5fc$method$sources$be35adaa73d45ae7(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_ast_SourceCollection__5fc$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_SourceCollection__5fc$method$visitChildren$3886f3a733ef8382(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_ast_SourceCollection__5fc$method_info$prettyPrint$323ca37cb40f93d3;
extern _jc_method _jc_polyglot_ext_jl_ast_SourceCollection__5fc$method_info$reconstruct$1013d1f0a1e6915f;
extern _jc_method _jc_polyglot_ext_jl_ast_SourceCollection__5fc$method_info$sources$c7962ae651ac0609;
extern _jc_method _jc_polyglot_ext_jl_ast_SourceCollection__5fc$method_info$sources$be35adaa73d45ae7;
extern _jc_method _jc_polyglot_ext_jl_ast_SourceCollection__5fc$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_ext_jl_ast_SourceCollection__5fc$method_info$visitChildren$3886f3a733ef8382;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_polyglot_ext_jl_ast_SourceCollection__5fc$method$class__24$57cd45dca0be1678(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$vmethods {
	void	(*prettyPrint$323ca37cb40f93d3)(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_polyglot_visit_PrettyPrinter$object *);
	struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object	*(*reconstruct$1013d1f0a1e6915f)(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_object *);
	struct _jc_object	*(*sources$c7962ae651ac0609)(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *);
	struct _jc_object	*(*sources$be35adaa73d45ae7)(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *);
	struct _jc_object	*(*visitChildren$3886f3a733ef8382)(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_Node__5fc$vmethods	polyglot_ext_jl_ast_Node__5fc;
	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$vmethods	polyglot_ext_jl_ast_SourceCollection__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$sub_refs {
	struct _jc_object	*sources;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$refs {
    _jc_polyglot_ext_jl_ast_SourceCollection__5fc$sub_refs	polyglot_ext_jl_ast_SourceCollection__5fc;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_refs	polyglot_ext_jl_ast_Node__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_nonrefs	polyglot_ext_jl_ast_Node__5fc;
    _jc_polyglot_ext_jl_ast_SourceCollection__5fc$sub_nonrefs	polyglot_ext_jl_ast_SourceCollection__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object {
	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtype _jc_polyglot_ext_jl_ast_SourceCollection__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_SourceCollection__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_SourceCollection__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_SourceCollection__5fc_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/ast/SourceCollection__5fc.h <==
// public class polyglot.ext.jl.ast.SourceCollection_c

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 687ec145cf1dbf5b polyglot_ext_jl_ast_Node__5fc
// @dep_class d7850567a307465c polyglot_ext_jl_ast_SourceCollection__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_ast_Node__5fc

#include "polyglot/ext/jl/ast/Node__5fc.h"

#ifndef _JC_polyglot_ext_jl_ast_SourceCollection__5fc_H_
#define _JC_polyglot_ext_jl_ast_SourceCollection__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_SourceCollection$object;
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object;
struct _jc_polyglot_util_CodeWriter$object;
struct _jc_polyglot_util_Position$object;
struct _jc_polyglot_visit_NodeVisitor$object;
struct _jc_polyglot_visit_PrettyPrinter$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$sub_refs	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$sub_nonrefs	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$refs	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$refs;
typedef struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$nonrefs	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$object;

typedef struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$fields_struct	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$fields_struct;
typedef const struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$vmethods	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtable	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtype	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtype;

// Class fields structure
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$fields_struct {
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24SourceFile;
};
extern _jc_polyglot_ext_jl_ast_SourceCollection__5fc$fields_struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$class_fields;

// Constructors
extern void _jc_polyglot_ext_jl_ast_SourceCollection__5fc$method$_init$a1fe22b707e2a2a8(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_polyglot_util_Position$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_polyglot_ext_jl_ast_SourceCollection__5fc$method$prettyPrint$323ca37cb40f93d3(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_polyglot_visit_PrettyPrinter$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *_jc_polyglot_ext_jl_ast_SourceCollection__5fc$method$reconstruct$1013d1f0a1e6915f(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_SourceCollection__5fc$method$sources$c7962ae651ac0609(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_SourceCollection__5fc$method$sources$be35adaa73d45ae7(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_ast_SourceCollection__5fc$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_SourceCollection__5fc$method$visitChildren$3886f3a733ef8382(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_ast_SourceCollection__5fc$method_info$prettyPrint$323ca37cb40f93d3;
extern _jc_method _jc_polyglot_ext_jl_ast_SourceCollection__5fc$method_info$reconstruct$1013d1f0a1e6915f;
extern _jc_method _jc_polyglot_ext_jl_ast_SourceCollection__5fc$method_info$sources$c7962ae651ac0609;
extern _jc_method _jc_polyglot_ext_jl_ast_SourceCollection__5fc$method_info$sources$be35adaa73d45ae7;
extern _jc_method _jc_polyglot_ext_jl_ast_SourceCollection__5fc$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_ext_jl_ast_SourceCollection__5fc$method_info$visitChildren$3886f3a733ef8382;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_polyglot_ext_jl_ast_SourceCollection__5fc$method$class__24$57cd45dca0be1678(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$vmethods {
	void	(*prettyPrint$323ca37cb40f93d3)(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_polyglot_visit_PrettyPrinter$object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object	*(*reconstruct$1013d1f0a1e6915f)(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*sources$c7962ae651ac0609)(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*sources$be35adaa73d45ae7)(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*visitChildren$3886f3a733ef8382)(_jc_env *, struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_Node__5fc$vmethods	polyglot_ext_jl_ast_Node__5fc;
	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$vmethods	polyglot_ext_jl_ast_SourceCollection__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$sub_refs {
	struct _jc_object	*sources;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$refs {
    _jc_polyglot_ext_jl_ast_SourceCollection__5fc$sub_refs	polyglot_ext_jl_ast_SourceCollection__5fc;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_refs	polyglot_ext_jl_ast_Node__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_nonrefs	polyglot_ext_jl_ast_Node__5fc;
    _jc_polyglot_ext_jl_ast_SourceCollection__5fc$sub_nonrefs	polyglot_ext_jl_ast_SourceCollection__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_SourceCollection__5fc$object {
	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_SourceCollection__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_SourceCollection__5fc$vtype _jc_polyglot_ext_jl_ast_SourceCollection__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_SourceCollection__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_SourceCollection__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_SourceCollection__5fc_H_ */
